@@ -86,26 +86,39 @@ class GraphEntity(AbstractEntity):
     iri_sentence: ClassVar[URIRef] = DOCO.Sentence
     iri_table: ClassVar[URIRef] = DOCO.Table
     iri_text_chunk: ClassVar[URIRef] = DOCO.TextChunk
+    iri_abstract: ClassVar[URIRef] = DOCO.Abstract
     iri_academic_proceedings: ClassVar[URIRef] = FABIO.AcademicProceedings
+    iri_audio_document: ClassVar[URIRef] = FABIO.AudioDocument
     iri_book: ClassVar[URIRef] = FABIO.Book
     iri_book_chapter: ClassVar[URIRef] = FABIO.BookChapter
     iri_book_series: ClassVar[URIRef] = FABIO.BookSeries
     iri_book_set: ClassVar[URIRef] = FABIO.BookSet
+    iri_computer_program: ClassVar[URIRef] = FABIO.ComputerProgram
     iri_data_file: ClassVar[URIRef] = FABIO.DataFile
+    iri_data_management_plan: ClassVar[URIRef] = FABIO.DataManagementPlan
+    iri_editorial: ClassVar[URIRef] = FABIO.Editorial
     iri_expression: ClassVar[URIRef] = FABIO.Expression
     iri_expression_collection: ClassVar[URIRef] = FABIO.ExpressionCollection
     iri_has_sequence_identifier: ClassVar[URIRef] = FABIO.hasSequenceIdentifier
     iri_journal: ClassVar[URIRef] = FABIO.Journal
     iri_journal_article: ClassVar[URIRef] = FABIO.JournalArticle
+    iri_journal_editorial: ClassVar[URIRef] = FABIO.JournalEditorial
     iri_journal_issue: ClassVar[URIRef] = FABIO.JournalIssue
     iri_journal_volume: ClassVar[URIRef] = FABIO.JournalVolume
     iri_manifestation: ClassVar[URIRef] = FABIO.Manifestation
+    iri_newspaper: ClassVar[URIRef] = FABIO.Newspaper
+    iri_newspaper_article: ClassVar[URIRef] = FABIO.NewspaperArticle
+    iri_newspaper_issue: ClassVar[URIRef] = FABIO.NewspaperIssue
+    iri_newspaper_editorial: ClassVar[URIRef] = FABIO.NewspaperEditorial
     iri_peer_review: ClassVar[URIRef] = FR.ReviewVersion
+    iri_preprint: ClassVar[URIRef] = FABIO.Preprint
+    iri_presentation: ClassVar[URIRef] = FABIO.Presentation
     iri_proceedings_paper: ClassVar[URIRef] = FABIO.ProceedingsPaper
     iri_proceedings_series: ClassVar[URIRef] = FABIO.Series
     iri_reference_book: ClassVar[URIRef] = FABIO.ReferenceBook
     iri_reference_entry: ClassVar[URIRef] = FABIO.ReferenceEntry
     iri_report_document: ClassVar[URIRef] = FABIO.ReportDocument
+    iri_retraction_notice: ClassVar[URIRef] = FABIO.RetractionNotice
     iri_series: ClassVar[URIRef] = FABIO.Series
     iri_specification_document: ClassVar[URIRef] = FABIO.SpecificationDocument
     iri_thesis: ClassVar[URIRef] = FABIO.Thesis
